@@ -12,9 +12,8 @@ def name(keyword):
     }
     response = requests.get('https://www.chtml.cn/w', params=params)
     page = BeautifulSoup(response.text, features="html.parser")
-    p_list = page.find_all('p')
     var_text = ''
-    for p in p_list[0:4]:
+    for p in page.find_all('p')[0:4]:
         var_text += (p.text + '\n')
 
     typer.echo(var_text)
